@@ -15,6 +15,7 @@
 """A Mongo driver for Python."""
 
 import types
+import sys
 
 from pymongo.connection import Connection as PyMongo_Connection
 from pymongo.son import SON
@@ -31,7 +32,7 @@ SLOW_ONLY = 1
 ALL = 2
 """Profile all operations."""
 
-version = "0.11.2"
+version = "0.11.3"
 """Current version of PyMongo."""
 
 Connection = PyMongo_Connection
@@ -46,6 +47,8 @@ def _index_list(key_or_list, direction):
     if direction is not None:
         return [(key_or_list, direction)]
     else:
+        if isinstance(key_or_list, types.StringTypes):
+            raise TypeError("must specify a direction if using a string key")
         return key_or_list
 
 
@@ -69,3 +72,14 @@ def _index_document(index_list):
                             "DESCENDING")
         index[key] = value
     return index
+
+def _reversed(l):
+    """A version of the `reversed()` built-in for Python 2.3.
+    """
+    i = len(l)
+    while i > 0:
+        i -= 1
+        yield l[i]
+
+if sys.version_info[:3] >= (2, 4, 0):
+    _reversed = reversed
