@@ -51,11 +51,11 @@ class Binary(str):
         self.__subtype = subtype
         return self
 
-    @property
     def subtype(self):
         """Get the subtype of this binary data.
         """
         return self.__subtype
+    subtype = property(subtype)
 
     def __eq__(self, other):
         if isinstance(other, Binary):
